@@ -7,16 +7,17 @@
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
-
+# pylint: disable=invalid-name
+"""Database migration."""
 from django.db import models, migrations
 from aiida.backends.djsite.db.migrations import upgrade_schema_version
 
-
 REVISION = '1.0.13'
 DOWN_REVISION = '1.0.12'
 
 
 class Migration(migrations.Migration):
+    """Database migration."""
 
     dependencies = [
         ('db', '0012_drop_dblock'),
