@@ -17,6 +17,7 @@ from aiida.cmdline.commands.cmd_data.cmd_export import data_export, export_optio
 from aiida.cmdline.commands.cmd_data.cmd_list import data_list, list_options
 from aiida.cmdline.params import arguments, options, types
 from aiida.cmdline.utils import decorators, echo
+from aiida.cmdline.utils.pluginable import Pluginable
 
 LIST_PROJECT_HEADERS = ['Id', 'Label', 'Formula']
 EXPORT_FORMATS = ['cif', 'xsf', 'xyz']
@@ -151,7 +152,7 @@ def structure_export(**kwargs):
     data_export(node, output, fmt, other_args=kwargs, overwrite=force)
 
 
-@structure.group('import')
+@structure.group('import', entry_point_group='aiida.cmdline.data.structure.import', cls=Pluginable)
 def structure_import():
     """Import a crystal structure from file into a StructureData object."""
 
@@ -180,9 +181,11 @@ def structure_import():
     default=[0, 0, 0],
     help='Set periodic boundary conditions for each lattice direction, where 0 means periodic and 1 means periodic.'
 )
+@click.option('--label', type=click.STRING, show_default=False, help='Set the structure node label (empty by default)')
+@options.GROUP()
 @options.DRY_RUN()
 @decorators.with_dbenv()
-def import_aiida_xyz(filename, vacuum_factor, vacuum_addition, pbc, dry_run):
+def import_aiida_xyz(filename, vacuum_factor, vacuum_addition, pbc, label, group, dry_run):
     """
     Import structure in XYZ format using AiiDA's internal importer
     """
@@ -211,14 +214,22 @@ def import_aiida_xyz(filename, vacuum_factor, vacuum_addition, pbc, dry_run):
     except (ValueError, TypeError) as err:
         echo.echo_critical(str(err))
 
+    if label:
+        new_structure.label = label
+
     _store_structure(new_structure, dry_run)
 
+    if group:
+        group.add_nodes(new_structure)
+
 
 @structure_import.command('ase')
 @click.argument('filename', type=click.Path(exists=True, dir_okay=False, resolve_path=True))
+@click.option('--label', type=click.STRING, show_default=False, help='Set the structure node label (empty by default)')
+@options.GROUP()
 @options.DRY_RUN()
 @decorators.with_dbenv()
-def import_ase(filename, dry_run):
+def import_ase(filename, label, group, dry_run):
     """
     Import structure with the ase library that supports a number of different formats
     """
@@ -235,4 +246,10 @@ def import_ase(filename, dry_run):
     except ValueError as err:
         echo.echo_critical(str(err))
 
+    if label:
+        new_structure.label = label
+
     _store_structure(new_structure, dry_run)
+
+    if group:
+        group.add_nodes(new_structure)
