@@ -130,13 +130,9 @@ def infer_calculation_entry_point(type_strings):
         inferred_entry_point_name = '.'.join(plugin_parts)
 
         if inferred_entry_point_name in entry_point_names:
-            entry_point_string = '{entry_point_group}:{entry_point_name}'.format(
-                entry_point_group=entry_point_group, entry_point_name=inferred_entry_point_name
-            )
+            entry_point_string = f'{entry_point_group}:{inferred_entry_point_name}'
         elif inferred_entry_point_name:
-            entry_point_string = '{plugin_name}.{plugin_class}'.format(
-                plugin_name=inferred_entry_point_name, plugin_class=plugin_class
-            )
+            entry_point_string = f'{inferred_entry_point_name}.{plugin_class}'
         else:
             # If there is no inferred entry point name, i.e. there is no module name, use an empty string as fall back
             # This should only be the case for the type string `calculation.job.JobCalculation.`
