@@ -9,17 +9,25 @@
 ###########################################################################
 # pylint: disable=cyclic-import
 """Components to communicate tasks to RabbitMQ."""
-import collections
+import asyncio
+from collections.abc import Mapping
 import logging
+import traceback
 
-from tornado import gen
 from kiwipy import communications, Future
+import pamqp.encode
 import plumpy
 
 from aiida.common.extendeddicts import AttributeDict
 
 __all__ = ('RemoteException', 'CommunicationTimeout', 'DeliveryFailed', 'ProcessLauncher', 'BROKER_DEFAULTS')
 
+# The following statement enables support for RabbitMQ 3.5 because without it, connections established by `aiormq` will
+# fail because the interpretation of the types of integers passed in connection parameters has changed after that
+# version. Once RabbitMQ 3.5 is no longer supported (it has been EOL since October 2016) this can be removed. This
+# should also allow to remove the direct dependency on `pamqp` entirely.
+pamqp.encode.support_deprecated_rabbitmq()
+
 LOGGER = logging.getLogger(__name__)
 
 RemoteException = plumpy.RemoteException
@@ -120,7 +128,7 @@ def _store_inputs(inputs):
         try:
             node.store()
         except AttributeError:
-            if isinstance(node, collections.Mapping):
+            if isinstance(node, Mapping):
                 _store_inputs(node)
 
 
@@ -146,14 +154,13 @@ class ProcessLauncher(plumpy.ProcessLauncher):
         """
         from aiida.engine import ProcessState
 
-        if not node.is_excepted:
+        if not node.is_excepted and not node.is_sealed:
             node.logger.exception(message)
-            node.set_exception(str(exception))
+            node.set_exception(''.join(traceback.format_exception(type(exception), exception, None)).rstrip())
             node.set_process_state(ProcessState.EXCEPTED)
             node.seal()
 
-    @gen.coroutine
-    def _continue(self, communicator, pid, nowait, tag=None):
+    async def _continue(self, communicator, pid, nowait, tag=None):
         """Continue the task.
 
         Note that the task may already have been completed, as indicated from the corresponding the node, in which
@@ -180,7 +187,7 @@ class ProcessLauncher(plumpy.ProcessLauncher):
             # we raise `Return` instead of `TaskRejected` because the latter would cause the task to be resent and start
             # to ping-pong between RabbitMQ and the daemon workers.
             LOGGER.exception('Cannot continue process<%d>', pid)
-            raise gen.Return(False) from exception
+            return False
 
         if node.is_terminated:
 
@@ -195,14 +202,18 @@ class ProcessLauncher(plumpy.ProcessLauncher):
             elif node.is_killed:
                 future.set_exception(plumpy.KilledError())
 
-            raise gen.Return(future.result())
+            return future.result()
 
         try:
-            result = yield super()._continue(communicator, pid, nowait, tag)
+            result = await super()._continue(communicator, pid, nowait, tag)
         except ImportError as exception:
             message = 'the class of the process could not be imported.'
             self.handle_continue_exception(node, exception, message)
             raise
+        except asyncio.CancelledError:  # pylint: disable=try-except-raise
+            # note this is only required in python<=3.7,
+            # where asyncio.CancelledError inherits from Exception
+            raise
         except Exception as exception:
             message = 'failed to recreate the process instance in order to continue it.'
             self.handle_continue_exception(node, exception, message)
@@ -215,4 +226,4 @@ class ProcessLauncher(plumpy.ProcessLauncher):
             LOGGER.exception('failed to serialize the result for process<%d>', pid)
             raise
 
-        raise gen.Return(serialized)
+        return serialized
