@@ -44,7 +44,7 @@ class List(Data, MutableSequence):
         return len(self.get_list())
 
     def __str__(self):
-        return super().__str__() + ' value: {}'.format(self.get_list())
+        return f'{super().__str__()} value: {self.get_list()}'
 
     def __eq__(self, other):
         try:
@@ -77,15 +77,19 @@ class List(Data, MutableSequence):
         del self[value]
 
     def pop(self, **kwargs):  # pylint: disable=arguments-differ
+        """Remove and return item at index (default last)."""
         data = self.get_list()
-        data.pop(**kwargs)
+        item = data.pop(**kwargs)
         if not self._using_list_reference():
             self.set_list(data)
+        return item
 
     def index(self, value):  # pylint: disable=arguments-differ
+        """Return first index of value.."""
         return self.get_list().index(value)
 
     def count(self, value):
+        """Return number of occurrences of value."""
         return self.get_list().count(value)
 
     def sort(self, key=None, reverse=False):
