@@ -7,11 +7,9 @@
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
-# pylint: disable=inconsistent-return-statements
 # Warning: this implementation is used directly in the documentation as a literal-include, which means that if any part
 # of this code is changed, the snippets in the file `docs/source/howto/codes.rst` have to be checked for consistency.
 """Parser for an `ArithmeticAddCalculation` job."""
-from aiida.orm import Int
 from aiida.parsers.parser import Parser
 
 
@@ -20,13 +18,10 @@ class ArithmeticAddParser(Parser):
 
     def parse(self, **kwargs):
         """Parse the contents of the output files stored in the `retrieved` output node."""
-        try:
-            output_folder = self.retrieved
-        except AttributeError:
-            return self.exit_codes.ERROR_NO_RETRIEVED_FOLDER
+        from aiida.orm import Int
 
         try:
-            with output_folder.open(self.node.get_option('output_filename'), 'r') as handle:
+            with self.retrieved.open(self.node.get_option('output_filename'), 'r') as handle:
                 result = int(handle.read())
         except OSError:
             return self.exit_codes.ERROR_READING_OUTPUT_FILE
@@ -37,3 +32,18 @@ class ArithmeticAddParser(Parser):
 
         if result < 0:
             return self.exit_codes.ERROR_NEGATIVE_NUMBER
+
+
+class SimpleArithmeticAddParser(Parser):
+    """Simple parser for an `ArithmeticAddCalculation` job (for demonstration purposes only)."""
+
+    def parse(self, **kwargs):
+        """Parse the contents of the output files stored in the `retrieved` output node."""
+        from aiida.orm import Int
+
+        output_folder = self.retrieved
+
+        with output_folder.open(self.node.get_option('output_filename'), 'r') as handle:
+            result = int(handle.read())
+
+        self.out('sum', Int(result))
